bayespy.inference.vmp.nodes.gaussian.GaussianGammaISOToGaussianGammaARD.move_plates
===================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaISOToGaussianGammaARD.move_plates